@@ -1,25 +1,15 @@
 #!/usr/bin/perl -w
-# $Revision: 1.12 $
+# $Revision: 1.8 $
 use strict;
-use Weather::Com::Simple;
+use Weather::Simple;
 
 $| = 1;
-
-# have a cvs driven version...
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.12 $ =~ /(\d+)/g;
-
-# you have to fill in your ids from weather.com here
-my $PartnerId  = '';
+my $PartnerId  = '';	# you have to fill in your ids from weather.com here
 my $LicenseKey = '';
 
-# if you need a proxy... maybe with authentication
-my $Proxy      = '';
-my $Proxy_User = '';
-my $Proxy_Pass = '';                     
-
 # debugging on/off
 my $debugmode = 0;
-if ( $ARGV[0] && ( $ARGV[0] eq "-d" ) ) {
+if ( $ARGV[0] && ($ARGV[0] eq "-d")) {
 	warn "Debug mode turned on.\n";
 	$debugmode = 1;
 }
@@ -28,14 +18,10 @@ my %weatherargs = (
 					'partner_id' => $PartnerId,
 					'license'    => $LicenseKey,
 					'debug'      => $debugmode,
-					'proxy'      => $Proxy,
-					'proxy_user' => $Proxy_User,
-					'proxy_pass' => $Proxy_Pass,
 );
 
 # print greeting
 print "\nWelcome to Uncle Tom's weather station...\n";
-print "This is V$VERSION\n";
 print "\nPlease enter a location name to look for, e.g\n";
 print "'Heidelberg' or 'Seattle, WA', or 'Munich, Germany'\n\n";
 
@@ -55,9 +41,8 @@ while ( chomp( my $input = <STDIN> ) ) {
 	last if ( $input =~ /^end|quit|exit$/ );
 
 	# add place to config hash and get weather
-	$weatherargs{'place'}      = $input;
-
-	my $ws      = Weather::Com::Simple->new(%weatherargs);
+	$weatherargs{'place'} = $input;
+	my $ws      = Weather::Simple->new(%weatherargs);
 	my $weather = $ws->get_weather();
 
 	# if $ws->get_weather() returned 'undef', we haven't found anything...
@@ -70,9 +55,7 @@ while ( chomp( my $input = <STDIN> ) ) {
 	# if we found anything we'll print it out...
 	# Weather::Simple allways returns an arrayref. maybe we found more
 	# than 1 location's weather
-	print "\nFound weather data for "
-	  . ( $#{$weather} + 1 )
-	  . " locations:\n\n";
+	print "\nFound weather data for " . ( $#{$weather} + 1 ) . " locations:\n\n";
 	foreach my $location_weather ( @{$weather} ) {
 
 		# print a nice heading underlined by '===='
@@ -106,7 +89,7 @@ __END__
 
 =head1 NAME
 
-weather.pl - Sample script to show the usage of the I<Weather::Com::Simple>
+weather.pl - Sample script to show the usage of the I<Weather::Simple>
 module
 
 =head1 SYNOPSIS
@@ -132,7 +115,7 @@ the script.
 
 The sample script I<weather.pl> asks you for a location name - either 
 a city or a 'city, region' or 'city, country' combination. It then uses 
-the I<Weather::Com::Simple> module to get the current weather conditions 
+the I<Weather::Simple> module to get the current weather conditions 
 for this location(s).
 
 If no location matching your input is found, a "no locations found" 
@@ -142,8 +125,8 @@ Else, the number of locations found is printed followed by nicely
 formatted weather data for each location.
 
 The command line parameter '-d' enables debugging mode (which is
-enabling debugging within all used packages (Weather::Com::Simple,
-Weather::Com::Cached, Weather::Com::Base).
+enabling debugging within all used packages (Weather::Simple,
+Weather::Cached, Weather::Com).
 
 =head1 AUTHOR
 
@@ -151,7 +134,7 @@ Thomas Schnuecker, E<lt>thomas@schnuecker.deE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004-2005 by Thomas Schnuecker
+Copyright (C) 2004 by Thomas Schnuecker
 
 This script is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
